@@ -1,5 +1,6 @@
-from . import Configuration, ApiClient
-from .apis.tags import (
+from .api_client import ApiClient
+from .configuration import Configuration
+from .api.reservations_api import (
     ReservationsApi,
 )
 
